List of available features
==========================

The following table provides an overview of the available featurest in the current version of TSFEL.

.. autosummary::
   :toctree: _generated
   :template: module_functions_template.rst

    tsfel.feature_extraction.features


.. include:: _generated/tsfel.feature_extraction.features.rst
